@@ -3,6 +3,7 @@ import logging
 from django.conf import settings
 from django.contrib.admin.models import LogEntry
 from django.contrib.auth.hashers import make_password
+from django.contrib.sessions.models import Session
 from django.core.management import call_command
 from django.db import connections
 
@@ -11,6 +12,7 @@ class AbstractScrubbingService:
     DEFAULT_USER_PASSWORD = 'Admin0404!'
 
     # Overwritable values
+    keep_session_data = False
     keep_scrubber_data = False
     keep_django_admin_log = False
     pre_scrub_functions = []
@@ -24,7 +26,7 @@ class AbstractScrubbingService:
 
     def _validation(self):
         if not settings.DEBUG:
-            self._logger.warning('Attention! Needs to be run in DEBUG mode!')
+            self._logger.warning('Attention! Has to run in DEBUG mode!')
             return False
 
         if 'django_scrubber' not in settings.INSTALLED_APPS:
@@ -63,11 +65,18 @@ class AbstractScrubbingService:
         if not self.keep_django_admin_log:
             LogEntry.objects.all().delete()
 
+        # Clear django session table
+        if not self.keep_session_data:
+            self._logger.info('Clearing data from "django_session" ...')
+            # Sessions might contain private information and furthermore cannot be used anyway because we anonymised
+            # all the users. Therefore it is being cleared by default
+            Session.objects.all().delete()
+
         # Reset scrubber data to avoid huge db dumps
         if not self.keep_scrubber_data:
-            self._logger.info('Scrubbing data from "scrub_data" ...')
-            # We truncate and don't scrub because the table is huge and will stay the same size if we just
-            # delete the records.
+            self._logger.info('Clearing data from "django_scrubber_fakedata" ...')
+            # We truncate and don't scrub because the table is huge and clearing on object-level might take a while.
+            # Furthermore can we avoid having a direct dependency to django-scrubber this way.
             cursor = connections['default'].cursor()
             cursor.execute('TRUNCATE TABLE django_scrubber_fakedata;')
 
